{# -*- coding: utf-8 -*-

  This file is part of Invenio.
  Copyright (C) 2015-2018 CERN.

  Invenio is free software; you can redistribute it and/or modify it
  under the terms of the MIT License; see LICENSE file for more details.
#}
{%- if breadcrumbs|length > 1 %}
  <div class="ui grid container">
    <div class="row">
      <div class="ui large breadcrumb" itemprop="breadcrumb">
        {%- for breadcrumb in breadcrumbs %}
          {%- if loop.last %}
            <a class="active section">
              {{ breadcrumb.text|safe }}
            </a>
          {%- else %}
            <a href="{{ breadcrumb.url }}" class="section">
              {{ breadcrumb.text|safe }}
            </a>
            <span class="divider">/</span>
          {%- endif %}
        {%- endfor %}
      </div>
    </div>
  </div>
{%- endif %}
